# Generated by roxygen2: do not edit by hand

export(assess_pkg_r_package)
export(average_issue_close_time)
export(bioconductor_reverse_deps)
export(build_dependency_tree)
export(check_and_fetch_cran_package)
export(check_cran_package)
export(count_commits_last_months)
export(cran_packages)
export(cran_revdep)
export(create_traceability_matrix)
export(dependsOnPkgs)
export(detect_version_conflicts)
export(download_and_parse_dependencies)
export(extract_package_version)
export(extract_thresholds_by_id)
export(extract_thresholds_by_key)
export(extract_version)
export(fetch_all_dependencies)
export(fetch_bioconductor_package_info)
export(fetch_bioconductor_releases)
export(generate_html_report)
export(generate_traceability_matrix)
export(get_bioconductor_package_url)
export(get_commits_since)
export(get_cran_package_url)
export(get_cran_total_downloads)
export(get_exports)
export(get_frugal_metrics)
export(get_github_data)
export(get_host_package)
export(get_internal_package_url)
export(get_package_download_bioconductor)
export(get_package_download_cran)
export(get_package_tarfile)
export(get_pkg_name)
export(get_pubmed_by_year)
export(get_pubmed_count)
export(get_risk_analysis)
export(get_risk_definition)
export(get_security_vulnerabilities)
export(get_session_dependencies)
export(get_suggested_exp_funcs)
export(get_versions)
export(install_package_local)
export(is_base)
export(list_badges)
export(modify_description_file)
export(parse_bioconductor_releases)
export(parse_html_version)
export(parse_package_info)
export(print_tree)
export(risk_assess_pkg)
export(risk_assess_pkg_lock_files)
export(set_up_pkg)
export(write_summary_report)
import(curl)
import(dplyr)
import(purrr)
import(utils)
import(xml2)
importFrom(BiocManager,repositories)
importFrom(BiocManager,version)
importFrom(curl,curl)
importFrom(curl,curl_fetch_memory)
importFrom(curl,handle_setheaders)
importFrom(curl,handle_setopt)
importFrom(curl,new_handle)
importFrom(desc,desc_coerce_authors_at_r)
importFrom(desc,description)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(fs,dir_exists)
importFrom(fs,path_abs)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(memoise,memoise)
importFrom(memoise,timeout)
importFrom(purrr,pluck)
importFrom(remotes,download_version)
importFrom(rlang,"%||%")
importFrom(rmarkdown,html_document)
importFrom(rmarkdown,md_document)
importFrom(rmarkdown,render)
importFrom(stats,setNames)
importFrom(stringr,str_trim)
importFrom(tools,file_ext)
importFrom(utils,download.file)
importFrom(utils,read.csv)
importFrom(utils,read.table)
importFrom(utils,sessionInfo)
importFrom(utils,tar)
importFrom(utils,untar)
importFrom(xml2,read_html)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
importFrom(xml2,xml_text)
