% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_risk_analysis.R
\name{get_risk_definition}
\alias{get_risk_definition}
\title{Get Risk Definition}
\usage{
get_risk_definition()
}
\value{
A list of risk configuration items.
}
\description{
Load risk definition config from options, JSON file, or fallback to bundled file.
}
\examples{
risk_rule <- get_risk_definition()
print(risk_rule)
}
