% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_covr_modes.R
\name{get_function_no_tests}
\alias{get_function_no_tests}
\title{get functions with no tests}
\usage{
get_function_no_tests(mapping_df)
}
\arguments{
\item{mapping_df}{- data frame with source files and test files}
}
\value{
no_tests_df - data frame with source files with no tests
}
\description{
get functions with no tests
}
\keyword{internal}
