% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run_covr_skip_stf.R
\name{create_covr_list_no_skip}
\alias{create_covr_list_no_skip}
\title{create covr_list when no tests are skipped}
\usage{
create_covr_list_no_skip(test_map, test_results_long, pkg_source_path, pkg)
}
\arguments{
\item{test_map}{- R object with mapped tests}

\item{test_results_long}{- cvr object with no tests skipped}

\item{pkg_source_path}{- path to the package}

\item{pkg}{- name of the package}
}
\value{
- summary cvr object
}
\description{
create covr_list when no tests are skipped
}
\keyword{internal}
