% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_risk_analysis.R
\name{compute_risk}
\alias{compute_risk}
\title{Compute Risk Level}
\usage{
compute_risk(value, risk)
}
\arguments{
\item{value}{The numeric or categorical value to evaluate.}

\item{risk}{A list describing the thresholds for the metric.}
}
\value{
The computed risk level (e.g. "low", "medium", "high").
}
\description{
Apply risk thresholds to compute risk level for a single metric.
}
\keyword{internal}
