% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/documentation_metrics.R
\name{build_rd_index}
\alias{build_rd_index}
\title{Build a fast lookup index for an Rd database}
\usage{
build_rd_index(db)
}
\arguments{
\item{db}{An Rd database list as returned by `tools::Rd_db()`.}
}
\value{
A list with elements `alias_index` (environment) and `topic_by_file` (named character vector).
}
\description{
Provides (1) an alias index, mapping `alias -> filename`, and
(2) a topic index, mapping `filename -> \\name` (topic).
}
\keyword{internal}
