% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_risk_analysis.R
\name{get_risk_analysis}
\alias{get_risk_analysis}
\title{Get Risk Analysis}
\usage{
get_risk_analysis(data)
}
\arguments{
\item{data}{The nested package metadata.}
}
\value{
A named list of computed risk levels.
}
\description{
Compute risk levels for the package metadata.
}
\examples{
# Minimal mock input for demonstration
mock_data <- list(
  dependencies_count = 5,
  later_version = 2,
  code_coverage = 0.75,
  last_month_download = 150000,
  license = "MIT",
  reverse_dependencies_count = 10,
  documentation_score = 2,
  has_examples = list(
    data = data.frame(
      function_name          = "somefunction",
      documentation_name     = "No documentation found",
      documentation_location = 0,
      example                = "no Rd file",
      stringsAsFactors       = FALSE
    ),
    example_score = 0.20   
  ),
  has_docs = list(
    data = data.frame(
      function_name    = "somefunction",
      stringsAsFactors = FALSE
    ),
    has_docs_score = 0.30  
  ),
  cmd_check = 0
)

get_risk_analysis(mock_data)
}
