% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/map_tests_stf.R
\name{map_test}
\alias{map_test}
\title{Map the hierarchy structure of a testthat test file}
\usage{
map_test(path)
}
\arguments{
\item{path}{character, path to file}
}
\value{
data.frame
}
\description{
Query a test file to see what expectations are defined in it.
}
\details{
Return data.frame containing which expectations are in the test file
 by context/description/test/expectation/linerange
}
\seealso{
\code{\link[utils]{getParseData}}

Other utility: 
\code{\link{create_coverage_skip_stf}()},
\code{\link{map_tests_stf}()}
}
\concept{utility}
